@@ -4,7 +4,8 @@
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
-#ifndef WIN32
+#ifndef _MSC_VER
+// No unistd.h in MS VC
 #include <unistd.h>
 #endif
 #include <time.h>
@@ -31,16 +32,17 @@
 #else
 #  define PTR2ul(p)	INT2PTR(unsigned long,p)	
 #endif
-
-
-#if defined __cygwin__ || __mingw32__ || _WIN32
-#include <windows.h>
-#include <process.h>
 #endif
 
+#if defined __cygwin__ || defined __mingw32__ || defined _MSC_VER
+#include <windows.h>
+#endif
 #if defined __darwin__
 #include <sys/file.h>
 #endif
+
+#ifdef _MSC_VER
+#include <process.h>
 #endif
 
 #if !defined _STDIR
@@ -52,8 +54,7 @@
 
 #define UUID_STATE			".UUID_STATE"
 #define UUID_NODEID			".UUID_NODEID"
-
-#if defined __cygwin__ || __mingw32__ || _WIN32
+#if defined __mingw32__ || defined _WIN32 || defined _MSC_VER
 #define UUID_STATE_NV_STORE		_STDIR"\\"UUID_STATE
 #define UUID_NODEID_NV_STORE		_STDIR"\\"UUID_NODEID
 #else
@@ -62,7 +63,7 @@
 #endif
 
 #define UUIDS_PER_TICK 1024
-#if defined(_WIN32)
+#ifdef _MSC_VER
 #define I64(C) C##i64
 #else
 #define I64(C) C##LL
@@ -75,8 +76,13 @@
 
 #define CHECK(f1, f2) if (f1 != f2) RETVAL = f1 < f2 ? -1 : 1;
 
-#if defined(_WIN32)
-//types not available on windows
+typedef unsigned int       unsigned32;
+typedef unsigned short     unsigned16;
+typedef unsigned char      unsigned8;
+typedef unsigned char      byte;
+#ifndef _MSC_VER
+typedef unsigned long long unsigned64_t;
+# else
 typedef __int64 int64_t;
 typedef unsigned __int64 uint64_t;
 typedef __int32 int32_t;
@@ -85,17 +91,12 @@ typedef __int16 int16_t;
 typedef unsigned __int16 uint16_t;
 typedef __int8 int8_t;
 typedef unsigned __int8 uint8_t;
+
+typedef unsigned __int64 unsigned64_t;
+// http://msdn2.microsoft.com/en-us/library/296az74e.aspx - Integer Limits
+
 typedef int pid_t;
-#else //SunCC or gcc
-#include <inttypes.h>
-#endif
-
-typedef uint32_t         unsigned32;
-typedef uint16_t         unsigned16;
-typedef uint8_t          unsigned8;
-typedef uint8_t          byte;
-typedef uint64_t         unsigned64_t;
-
+#endif /* _MSC_VER */
 typedef unsigned64_t       perl_uuid_time_t;
 
 #if   defined __solaris__ || defined __linux__
